from setuptools import setup

setup(name='distributions_spovi',
      version='0.2',
      description='Gaussian distributions',
      packages=['distributions_spovi'],
      author = 'SPoVi',
      author_email = 'snop.vlc@gmail.com',
      zip_safe=False)

# Can include author_email = "@gmail.com"